@@ -54,6 +54,7 @@ class SqliteDocumentPersistence(object):
 
         self.current_filename = filename
         self.connection = sqlite3.connect(filename)
+        self.connection.execute("PRAGMA journal_mode=OFF")
 
         if is_new:
             self.__build_db()
@@ -160,7 +161,7 @@ class SqliteDocumentPersistence(object):
         return clean
 
     def __update_metadata(self, cursor):
-        document_metadata = {'version': Document.CURRENT_VERSION, 'metadata': self.document.metadata,
+        document_metadata = {'version': Document.CURRENT_VERSION, 'metadata': self.document.metadata.to_dict(),
                              'source': self.__clean_none_values(dataclasses.asdict(self.document.source)),
                              'mixins': self.document.get_mixins(),
                              'taxonomies': self.document.taxonomies,
@@ -238,6 +239,24 @@ class SqliteDocumentPersistence(object):
 
         return new_node
 
+    def __rebuild_from_document(self):
+        cursor = self.connection.cursor()
+        cursor.execute("DELETE FROM cn")
+        cursor.execute("DELETE FROM cnp")
+        cursor.execute("DELETE FROM f")
+        cursor.execute("DELETE FROM f_value")
+
+        self.__update_metadata(cursor)
+        if self.document.content_node:
+            self.__insert_node(self.document.content_node, cursor)
+
+        cursor.close()
+        self.connection.commit()
+
     def get_bytes(self):
+
+        # TODO we need to make this an option?
+        self.__rebuild_from_document()
+
         with open(self.current_filename, 'rb') as f:
             return f.read()
